pub struct RequestOptions {
pub path: HashMap<String, String>,
pub query: HashMap<String, Value>,
pub headers: HashMap<String, String>,
pub body: Option<Value>,
}Expand description
HTTP request options compatible with OpenCode API endpoints.
Fields
path: HashMap<String, String>Path parameters used to replace placeholders in endpoint template.
query: HashMap<String, Value>Query string parameters.
headers: HashMap<String, String>Request headers.
body: Option<Value>JSON body payload.
Implementations
Sourceimpl RequestOptions
impl RequestOptions
Sourcepub fn with_path(self, key: impl Into<String>, value: impl Into<String>) -> Self
pub fn with_path(self, key: impl Into<String>, value: impl Into<String>) -> Self
Adds or overrides one path parameter.
These values are used to render placeholders such as {sessionID}.
Sourcepub fn with_query(self, key: impl Into<String>, value: Value) -> Self
pub fn with_query(self, key: impl Into<String>, value: Value) -> Self
Adds or overrides one query parameter.