pub async fn create_opencode(
options: Option<OpencodeServerOptions>,
) -> Result<Opencode>Expand description
Creates a local OpenCode server and a client bound to its discovered URL.
pub async fn create_opencode(
options: Option<OpencodeServerOptions>,
) -> Result<Opencode>Creates a local OpenCode server and a client bound to its discovered URL.